@@ -203,19 +203,19 @@ class Player:
         Called after each roll of the dice.
         """
         self.t_scorecard = [
-            [0, [], 0],
-            [0, [], 0],
-            [0, [], 0],
-            [0, [], 0],
-            [0, [], 0],
-            [0, [], 0],
-            [0, [], 0],
-            [0, [], 0],
-            [0, [], 0],
-            [0, [], 0],
-            [0, [], 0],
-            [0, [], 0],
-            [0, [], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
+            [0, [0, 0, 0, 0, 0], 0],
         ]
 
     def _calculate_top_half(self):
